@@ -5,7 +5,7 @@ BEGIN {
   use Exporter;
   use vars qw($VERSION @ISA @EXPORT_OK);
 
-  $VERSION = '0.012';
+  $VERSION = '0.013';
   @ISA = qw(Exporter);
 
   @EXPORT_OK = qw(
@@ -70,7 +70,16 @@ ln=target:pi=38;5;126:ow=33;1;38;5;208:di=38;5;30:*.pm=33;1;38;5;197:
 *.r100=38;5;244:*.r101=38;5;240:*.r102=38;5;241:*.r103=38;5;242:
 *.r104=38;5;243:*.r105=38;5;244:*.r106=38;5;245:*.r107=38;5;246:*.r108=38;5;247:
 *.r109=38;5;248:*.r110=38;5;249:*.r111=38;5;250:*.r112=38;5;251:*.r113=38;5;252:
-*.r114=38;5;253:*.r115=38;5;254:*.r116=38;5;255';
+*.r114=38;5;253:*.r115=38;5;254:*.r116=38;5;255:*.enc=38;5;110;3:
+*.map=38;5;58;3:*.mf=38;5;220;3:*.tfm=38;5;64:*.pfb=38;5;64:*.pfm=38;5;64:
+*.afm=38;5;64:*.def=38;5;136:*.mtx=38;5;36;3:*.tex=38;5;172:*.etx=38;5;36;3:
+*.sty=38;5;58:*.cfg=1:*.properties=38;5;197;1:*.m4=38;5;196;3:*.tfnt=38;5;140:
+*.tcl=38;5;64;1:*.typelib=38;5;49:*.pfa=38;5;43:*.sed=38;5;130;1:
+*.awk=38;5;148;1:*.svg=38;5;24;1:*.ttf=38;5;69;1:*.sample=38;5;225;1:
+*.example=38;5;225;1
+
+';
+
 
 $internal_ls_color =~ s/\n//g;
 
@@ -108,7 +117,7 @@ sub ls_color {
   for my $file(@files) {
     my($ext) = $file =~ m/^.*\.(.+)$/m;
     for my $ft(keys(%{$ls_colors})) {
-      if($ext eq $ft) {
+      if($ft eq $ext) {
       # 38;5;100;1m
         if($ls_colors->{$ft} =~ m/;(\d+;?[1-9]?)$/m) {
           my $n = $1;
